@@ -1,29 +1,41 @@
-require 'builder'
-
 module ActiveSupport #:nodoc:
   module CoreExtensions #:nodoc:
     module Array #:nodoc:
       module Conversions
         # Converts the array to a comma-separated sentence where the last element is joined by the connector word. Options:
-        # * <tt>:connector</tt> - The word used to join the last element in arrays with two or more elements (default: "and")
-        # * <tt>:skip_last_comma</tt> - Set to true to return "a, b and c" instead of "a, b, and c".        
-        def to_sentence(options = {})          
-          options.assert_valid_keys(:connector, :skip_last_comma, :locale)
-          
-          default = I18n.translate(:'support.array.sentence_connector', :locale => options[:locale])
-          default_skip_last_comma = I18n.translate(:'support.array.skip_last_comma', :locale => options[:locale])
-          options.reverse_merge! :connector => default, :skip_last_comma => default_skip_last_comma
-          options[:connector] = "#{options[:connector]} " unless options[:connector].nil? || options[:connector].strip == ''
+        # * <tt>:words_connector</tt> - The sign or word used to join the elements in arrays with two or more elements (default: ", ")
+        # * <tt>:two_words_connector</tt> - The sign or word used to join the elements in arrays with two elements (default: " and ")
+        # * <tt>:last_word_connector</tt> - The sign or word used to join the last element in arrays with three or more elements (default: ", and ")
+        def to_sentence(options = {})
+          default_words_connector     = I18n.translate(:'support.array.words_connector',     :locale => options[:locale])
+          default_two_words_connector = I18n.translate(:'support.array.two_words_connector', :locale => options[:locale])
+          default_last_word_connector = I18n.translate(:'support.array.last_word_connector', :locale => options[:locale])
 
+          # Try to emulate to_senteces previous to 2.3
+          if options.has_key?(:connector) || options.has_key?(:skip_last_comma)
+            ::ActiveSupport::Deprecation.warn(":connector has been deprecated. Use :words_connector instead", caller) if options.has_key? :connector
+            ::ActiveSupport::Deprecation.warn(":skip_last_comma has been deprecated. Use :last_word_connector instead", caller) if options.has_key? :skip_last_comma
+
+            skip_last_comma = options.delete :skip_last_comma
+            if connector = options.delete(:connector)
+              options[:last_word_connector] ||= skip_last_comma ? connector : ", #{connector}"
+            else
+              options[:last_word_connector] ||= skip_last_comma ? default_two_words_connector : default_last_word_connector
+            end
+          end
+          
+          options.assert_valid_keys(:words_connector, :two_words_connector, :last_word_connector, :locale)       
+          options.reverse_merge! :words_connector => default_words_connector, :two_words_connector => default_two_words_connector, :last_word_connector => default_last_word_connector
+          
           case length
             when 0
               ""
             when 1
               self[0].to_s
             when 2
-              "#{self[0]} #{options[:connector]}#{self[1]}"
+              "#{self[0]}#{options[:two_words_connector]}#{self[1]}"
             else
-              "#{self[0...-1].join(', ')}#{options[:skip_last_comma] ? '' : ','} #{options[:connector]}#{self[-1]}"
+              "#{self[0...-1].join(options[:words_connector])}#{options[:last_word_connector]}#{self[-1]}"
           end
         end
         
@@ -149,6 +161,7 @@ module ActiveSupport #:nodoc:
         #
         def to_xml(options = {})
           raise "Not all elements respond to to_xml" unless all? { |e| e.respond_to? :to_xml }
+          require 'builder' unless defined?(Builder)
 
           options[:root]     ||= all? { |e| e.is_a?(first.class) && first.class.to_s != "Hash" } ? first.class.to_s.underscore.pluralize : "records"
           options[:children] ||= options[:root].singularize
